==> kubernetes-model-1.0.63-sources.jar: io/fabric8/kubernetes/api/model/extensions/IngressStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class IngressStatusBuilder extends IngressStatusFluentImpl<IngressStatusBuilder> implements VisitableBuilder<IngressStatus,IngressStatusBuilder>{

    IngressStatusFluent<?> fluent;
    Boolean validationEnabled;

    public IngressStatusBuilder(){
            this(true);
    }
    public IngressStatusBuilder(Boolean validationEnabled){
            this(new IngressStatus(), validationEnabled);
    }
    public IngressStatusBuilder(IngressStatusFluent<?> fluent){
            this(fluent, true);
    }
    public IngressStatusBuilder(IngressStatusFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new IngressStatus(), validationEnabled);
    }
    public IngressStatusBuilder(IngressStatusFluent<?> fluent,IngressStatus instance){
            this(fluent, instance, true);
    }
    public IngressStatusBuilder(IngressStatusFluent<?> fluent,IngressStatus instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withLoadBalancer(instance.getLoadBalancer()); 
            this.validationEnabled = validationEnabled; 
    }
    public IngressStatusBuilder(IngressStatus instance){
            this(instance,true);
    }
    public IngressStatusBuilder(IngressStatus instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withLoadBalancer(instance.getLoadBalancer()); 
            this.validationEnabled = validationEnabled; 
    }

    public IngressStatus build(){
            IngressStatus buildable = new IngressStatus(fluent.getLoadBalancer());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            IngressStatusBuilder that = (IngressStatusBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.67-sources.jar: io/fabric8/kubernetes/api/model/extensions/IngressStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class IngressStatusBuilder extends IngressStatusFluentImpl<IngressStatusBuilder> implements VisitableBuilder<IngressStatus,IngressStatusBuilder>{

    IngressStatusFluent<?> fluent;
    Boolean validationEnabled;

    public IngressStatusBuilder(){
            this(true);
    }
    public IngressStatusBuilder(Boolean validationEnabled){
            this(new IngressStatus(), validationEnabled);
    }
    public IngressStatusBuilder(IngressStatusFluent<?> fluent){
            this(fluent, true);
    }
    public IngressStatusBuilder(IngressStatusFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new IngressStatus(), validationEnabled);
    }
    public IngressStatusBuilder(IngressStatusFluent<?> fluent,IngressStatus instance){
            this(fluent, instance, true);
    }
    public IngressStatusBuilder(IngressStatusFluent<?> fluent,IngressStatus instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withLoadBalancer(instance.getLoadBalancer()); 
            this.validationEnabled = validationEnabled; 
    }
    public IngressStatusBuilder(IngressStatus instance){
            this(instance,true);
    }
    public IngressStatusBuilder(IngressStatus instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withLoadBalancer(instance.getLoadBalancer()); 
            this.validationEnabled = validationEnabled; 
    }

    public IngressStatus build(){
            IngressStatus buildable = new IngressStatus(fluent.getLoadBalancer());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            IngressStatusBuilder that = (IngressStatusBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
